from viset.weizmannhorses import WeizmannHorsesSingleScale
from viset.dataset import Viset
from viset.show import imshow

def main():
  dbfile = WeizmannHorsesSingleScale().export()
  db = Viset(dbfile, datastep=1, async=False, verbose=True)
  for (im,annotation) in db[0]:
    imshow(im, title='horses')
    imshow(annotation['mask'], title='mask')
    
if __name__ == '__main__':
  main()

  
